12.0.1.2.0 (2022-12-16)
~~~~~~~~~~~~~~~~~~~~~~~

**Bugfixes**

- Repair UI bug where there are two left-hand entries for changing shifts settings
  in the settings interface. (`#488 <https://github.com/beescoop/Obeesdoo/issues/488>`_)
